Crate rulox_types

Crate rulox_types 

rulox_types is a collection of types used by the rulox crate to represent dynamically typed values.

Structs

LoxArgs
Arguments to a Lox function.
LoxClass
A class defined in Lox code.
LoxError
An error raised during compilation or execution.
LoxFn
A function defined in Lox code.
LoxInstance
An instance of a Lox class.
LoxVariable
A variable defined in Lox code.
MapKey
A hashmap key.

Enums

IntoIter
An iterator over a LoxValue::Array or a LoxValue::String.
LoxValue
A dynamically typed value used by Lox programs.

Traits

ConcreteLoxArgs
A trait for tuples than can be extracted from a LoxArgs.
Downcast
Objects which can be downcast to a concrete type.
LoxObject
A trait for foreign objects that can be used in Lox.

Functions

read
Returns a read-only RAII guard for the shared pointer.
write
Returns a read-write RAII guard for the shared pointer.

Type Aliases

DynLoxObject
A convenient alias for a LoxObject trait object.
LoxResult
A result returned from most Lox operations.